@@ -16,31 +16,23 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: computers-groups-batch-del.php,v 1.2.4.1 2003/10/04 07:31:31 theatrus Exp $
-#
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
-commonHeader("IRM Computers - Delete from Group Completed");
+commonHeader(_("Computers") . " - " . _("Delete from Group Completed"));
 $query = stripslashes($outquery);
 $query = stripslashes($query);
-$sth = $adb->prepare($query);
-if($sth)
+$DB = Config::Database();
+$data = $DB->getAll($query);
+foreach ($data as $result)
 {
-	$res = $sth->execute();
-	$numRows = $sth->rows();
-	for($i = 0; $i < $numRows; $i++)
-	{
-		$result = $sth->fetchrow_hash();
-  	$cID = $result["ID"];
+  	$cID = $DB->getTextValue($result["ID"]);
   	$query3 = "DELETE FROM comp_group where (comp_id = $cID)";
-		$result2 = $adb->dbh_do($query3);
-	}
-} else
-{
-	PRINT "Could not prepare query: ".$sth->errstr."<br>\n";
+	$DB->query($query3);
 }
-PRINT "The delete from group operation has been completed.";
+
+__("The delete from group operation has been completed.");
 commonFooter();
-?>
