@@ -16,31 +16,25 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: computers-software-batch-add.php,v 1.2.4.1 2003/02/24 16:48:09 racer Exp $
-#
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("admin");
-commonHeader("IRM Computers - Batch Software Add Completed");
+commonHeader(_("Computers") . " - " . _("Batch Software Add Completed"));
 $query = stripslashes($query);
 $query = stripslashes($query);
-$sth = $adb->prepare($query);
-if($sth)
+
+$DB = Config::Database();
+$data = $DB->getAll($query);
+foreach ($data as $result)
 {
-	$res = $sth->execute();
-	$numRows = $sth->rows();
-	for ($i = 0; $i < numRows; $i++)
-	{
-		$result = $sth->fetchrow_hash();
-		$cID = $result["ID"];
-		$query3 = "INSERT INTO inst_software VALUES (NULL, $cID, $sID)";	
-		$count = $adb->dbh_do($query3);
-	}
-} else
-{
-	PRINT "Could not prepare query: ".$sth->errstr."<br>\n";
+	$vals = array(
+		'cID' => $result['ID'],
+		'sID' => $sID
+		);
+	$DB->InsertQuery('inst_software', $vals);
 }
-PRINT "The batch add operation has been completed.";
+
+__("The batch add operation has been completed.");
 commonFooter();
-?>
