@@ -18,17 +18,13 @@
 #
 #
 ################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("post-only");
 
-commonHeader("IRM Frequently Asked Question - Detailed View");
-?>
-<?php
+commonHeader(_("Frequently Asked Questions") . " - " . _("Detailed View"));
+
 kbdisplayfullarticle($ID);
 commonFooter();
-?>
