@@ -18,18 +18,16 @@
 #
 #
 ################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-################################################################################
 
 include("../include/irm.inc");
-
+require_once 'include/i18n.php';
 AuthCheck("post-only");
 
-commonHeader("IRM Frequently Asked Questions");
+commonHeader(_("Frequently Asked Questions"));
+
+__("This is the IRM FAQ system. It allows you to view the questions most 
+frequently asked of the helpdesk.");
 ?>
-This is the IRM FAQ system. It allows you to view the questions most 
-frequently asked of the helpdesk.
 <br>
 <BR>
 <table border=0 width=100%>
@@ -39,4 +37,3 @@ frequently asked of the helpdesk.
 <?php
 faqdisplaycategories();
 commonFooter();
-?>
