@@ -16,21 +16,19 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: knowledgebase-article-delete.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  8/16/99 - Keith Schoenefeld:	Added this file for group stuff                #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
-commonHeader("IRM Knowledge Base - Article Deleted");
-$query = "DELETE FROM kbarticles WHERE (ID = \"$ID\")";
-$count = $adb->dbh_do($query);
-PRINT "Deleted the knowledge base article. <a href=\"$USERPREFIX/knowledgebase-index.php\">Go Back</a>";
+commonHeader(_("Knowledge Base") . " - " . _("Article Deleted"));
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$query = "DELETE FROM kbarticles WHERE (ID = $ID)";
+$DB->query($query);
+__('Deleted the knowledge base article.');
+printf('<a href="%s">%s</a>', Config::AbsLoc('users/knowledgebase-index.php'), _('Go Back'));
 commonFooter();
-?>
