@@ -18,23 +18,20 @@
 #
 #
 ################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("post-only");
 
-commonHeader("IRM Knowledge Base - Detailed View");
-if($addtofaq == "yes")
+commonHeader(_("Knowledge Base") . " - " . _("Detailed View"));
+if(@$addtofaq == "yes")
 {
 	kbaddtofaq($ID);
-} else if($removefromfaq == "yes")
+} else if(@$removefromfaq == "yes")
 {
 	kbremovefromfaq($ID);
 }
 kbdisplayfullarticle($ID);
 kbisfaq($ID);
 commonFooter();
-?>
