@@ -18,28 +18,24 @@
 #
 #
 ################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("post-only");
 
-commonHeader("IRM Knowledge Base");
-?>
-This is the IRM Knowledge Base system. It allows you to view all of the 
-knowledge base articles that have been entered.
+commonHeader(_("Knowledge Base"));
+_("This is the IRM Knowledge Base system. It allows you to view all of the knowledge base articles that have been entered."); ?>
 <br>
 <BR>
 <table border=0 width=100%>
 <tr>
-<?php
-PRINT "<td align=center><h4><a href=\"$USERPREFIX/knowledgebase-article-add.php\">Add an Article</a>";
-?>
-		</h4></td></tr>
+<td align=center>
+<h4>
+<a href="<?php echo Config::AbsLoc('users/knowledgebase-article-add.php') ?>">
+Add an Article</a>
+</h4></td></tr>
 </TABLE>
 <?php
 kbdisplaycategories();
 commonFooter();
-?>
