@@ -16,20 +16,24 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: license-add.php,v 1.3.2.2 2003/12/23 06:23:22 theatrus Exp $
-#
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 
-if ( $oem_sticker ) {
+if ( @$oem_sticker ) {
 	$oem_sticker="Yes";
 } else {
 	$oem_sticker="No";
 }
-$query = "INSERT INTO software_licenses  
-	( sID, licensekey, entitlement, oem_sticker )
-	VALUES 	('$sID','$licensekey','$entitlement','$oem_sticker')";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-?>
+$vals = array(
+	'sID' => $sID,
+	'licensekey' => $licensekey,
+	'entitlement' => $entitlement,
+	'oem_sticker' => $oem_sticker
+	);
+
+
+$DB = Config::Database();
+$DB->InsertQuery('software_licenses', $vals);
+header("Location: ".appendURLArguments($_SESSION['_sess_prevpage'], array('ID' => $sID)));
