@@ -16,12 +16,15 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: license-del.php,v 1.3 2003/02/10 04:24:24 racer Exp $
-#
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "DELETE FROM software_licenses  WHERE (ID=$lID)";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-?>
+$DB = Config::Database();
+if ($_REQUEST['lID'])
+{
+	$lID = $DB->getTextValue($_REQUEST['lID']);
+	$query = "DELETE FROM software_licenses WHERE (ID=$lID)";
+	$DB->query($query);
+}
+header("Location: ".$_SESSION['_sess_prevpage']);
