@@ -16,19 +16,10 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: logout.php,v 1.3 2001/07/06 02:11:52 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
-#  7/25/99 - Yann Ramin: Blanked cookies correctly.
-#  8/03/99 - Yann Ramin: Closed SQL connection
 ################################################################################
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
+
 session_destroy();
-header("Location: $UPREFIX");
-?>    
-
-
+header("Location: ".Config::AbsLoc(''));
