@@ -16,18 +16,17 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: networking-connect.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  3/17/00 - Yann Ramin: Added file to allow port operations (disconnect, connect)
 ################################################################################
 
 include("../include/irm.inc");
-
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "INSERT INTO networking_wire VALUES (NULL, $pID, $pID1)";
-$count = $adb->dbh_do($query);
+
+$vals = array(
+	'end1' => $pID,
+	'end2' => $pID1
+	);
+$DB = Config::Database();
+$DB->InsertQuery('networking_wire', $vals);
 header("Location: $go_back");
