@@ -16,34 +16,22 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: networking-info.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  4/9/200 - Added file  Sort of adhoc - I really want tracking on these thins. #
 ################################################################################
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("normal");
 
-commonHeader("IRM Networking - Device Information");
+commonHeader(_("Networking") . " - " . _("Device Information"));
 
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
 $query = "SELECT ID FROM networking WHERE (ID = $ID)";
-$sth = $adb->prepare($query);
-if($sth)
+$data = $DB->getAll($query);
+foreach ($data as $result)
 {
-	$res = $sth->execute();
-	$numRows = $sth->rows();
-	for($i = 0; $i < $numRows; $i++)
-	{
-		$result = $sth->fetchrow_hash();
   	$ID = $result["ID"];
   	showNetworking($ID);
-	}
-} else
-{
-	PRINT "Could not prepare query: ".$sth->errstr."<br>\n";
 }
 commonFooter();
-?>
