@@ -16,21 +16,17 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: networking-port-discon.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  4/11/00 - Yann Ramin  Networking code 101 				. #
 ################################################################################
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
 $query = "DELETE FROM networking_wire WHERE (end1 = $ID OR end2 = $ID)";
-$count = $adb->dbh_do($query);
-logevent($ID, "networking", 5, "port", "$IRMName disconnected port");
-header("Location: $HTTP_REFERER");
-?>
-
+$DB->query($query);
+logevent($ID, _("networking"), 5, _("port"), sprintf(_("%s disconnected port"),$IRMName));
+header("Location: ".$_SESSION['_sess_prevpage']);
