@@ -16,20 +16,25 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: networking-port-update.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  3/17/00 - Yann Ramin: Added file to allow port operations (disconnect, connect)
 ################################################################################
 
 include("../include/irm.inc");
-
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "REPLACE networking_ports VALUES ($ID, $device, $device_type, '$iface', '$ifaddr', '$ifmac', '$logical_number', '$name')";
-$result = $adb->dbh_do($query);
 
-header("Location: $HTTP_REFERER");
-?>
+$vals = array(
+	'device_on' => $device,
+	'device_type' => $device_type,
+	'iface' => $iface,
+	'ifaddr' => $ifaddr,
+	'ifmac' => $ifmac,
+	'logical_number' => $logical_number,
+	'name' => $name
+	);
+		
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$DB->UpdateQuery('networking_ports', $vals, "ID=$ID");
+
+header("Location: ".$_SESSION['_sess_prevpage']);
