@@ -16,25 +16,27 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: passwd-change.php,v 1.3 2001/07/10 18:44:06 racer Exp $
-#
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("normal");
 
-commonHeader("IRM - Change Password");
-if($IRMPass != md5($oldpassword))
+commonHeader(_("User") . " - ". _("Change Password"));
+$user = new User($_SESSION['_sess_username']);
+
+if ($_REQUEST['newpassword'] != $_REQUEST['confirm'])
 {
-  PRINT "You have incorrectly entered your old password.";
-} elseif ($newpassword != $confirm)
+	__("Your new password does not match the confirmation password.  They must be the same.");
+}
+elseif (!$user->authenticate($_SESSION['_sess_username'], $_REQUEST['oldpassword']))
 {
-	PRINT "Your new password does not match the confirmation password.  They must be the same.";
-} else
+	__("You have incorrectly entered your old password.");
+}
+else
 {
-	$user = new User($IRMName);
-	$user->setPassword($newpassword);
+	$user->setPassword($_REQUEST['newpassword']);
 	$user->commit();
+	__("Password successfully updated.\n");
 }
 
 commonFooter();
-?>
