@@ -16,13 +16,23 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
-$query = "INSERT INTO $tablename VALUES ('$name')";
-$count = $adb->dbh_do($query);
-logevent(-1, "IRM", 5, "setup", "$IRMName added entry $name to $tablename.");
-header("Location: $HTTP_REFERER");
-?>
+
+if (!preg_match('/^[a-zA-Z0-9_]+$/', $tablename))
+{
+	trigger_error(sprintf(_("Invalid table name: %s"),$tablename), E_USER_ERROR);
+}
+else
+{
+	$name = $DB->getTextValue($name);
+	$query = "INSERT INTO $tablename VALUES ($name)";
+	$DB = Config::Database();
+	$DB->query($query);
+}
+
+logevent(-1, "IRM", 5, _("setup"), sprintf(_("%s added entry %s to %s."),$IRMName,$name,$tablename));
+header("Location: ".$_SESSION['_sess_prevpage']);
