@@ -16,13 +16,21 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 include("../include/irm.inc");
-header("Location: $HTTP_REFERER");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
-$query = "DELETE FROM $tablename WHERE (name = \"$name\")";
-$count = $adb->dbh_do($query);
-logevent(-1, "IRM", 5, "setup", "$IRMName removed entry $name from $tablename."); 
-?>
+
+header("Location: ".$_SESSION['_sess_prevpage']);
+
+if (!preg_match('/^[A-Za-z0-9_]+$/', $tablename))
+{
+	trigger_error(sprintf(_("Invalid table name: %s"),$tablename), E_USER_ERROR);
+}
+
+$DB = Config::Database();
+$qname = $DB->getTextValue($name);
+$query = "DELETE FROM $tablename WHERE (name = $qname)";
+$DB->query($query);
+logevent(-1, _("IRM"), 5, _("setup"), sprintf(_("%s removed entry %s from %s."),$IRMName,$name,$tablename));
