@@ -16,31 +16,22 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-fasttrack-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 $templname = htmlspecialchars($templname);
 $contents = htmlspecialchars($contents);
 $solution = htmlspecialchars($solution);
-$query = "INSERT INTO fasttracktemplates VALUES (NULL, '$templname', '$priority', '$contents',
-		'$solution')";
-$result = $adb->dbh_do($query);
+$vals = array(
+	'name' => $templname,
+	'priority' => $priority,
+	'request' => $contents,
+	'response' => $solution
+	);
+$DB = Config::Database();
+$DB->InsertQuery('fasttracktemplates', $vals);
 
-if ($result == 1)
-{
-  header("Location: $HTTP_REFERER?add=1\n\n");
-
-}
-if ($result != 1)
-{
-  commonHeader("IRM Setup - FastTrack Template Add Error");
-}
-?>
+header("Location: ".appendURLArguments($_SESSION['_sess_prevpage'], array('add' => 1)));
