@@ -16,15 +16,14 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-fasttrack-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 
-header("Location: $HTTP_REFERER");
-$query = "DELETE FROM fasttracktemplates WHERE (ID = \"$ID\")";
-$count = $adb->dbh_do($query);
-
-?>
+header("Location: ".$_SESSION['_sess_prevpage']);
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$query = "DELETE FROM fasttracktemplates WHERE (ID = $ID)";
+$DB->query($query);
