@@ -16,27 +16,21 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-fasttrack-update.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 
+$vals = array(
+	'name' => $templname,
+	'priority' => $priority,
+	'request' => $contents,
+	'response' => $solution
+	);
 
-$templname = htmlspecialchars($templname);
-$contents = htmlspecialchars($contents);
-$solution = htmlspecialchars($solution);
-
-$query = "REPLACE fasttracktemplates VALUES ('$ID', '$templname', '$priority', '$contents', '$solution')";
-
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-
-?>
-
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$DB->UpdateQuery('fasttracktemplates', $vals, "ID=$ID");
+header("Location: ".$_SESSION['_sess_prevpage']);
