@@ -16,22 +16,20 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-groups-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  8/16/99 - Keith Schoenefeld:	Created file for groups stuff.                 #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
-commonHeader("IRM Group Setup - Group Added");
-$query = "INSERT INTO groups VALUES (null, '$groupname')";
-$count = $adb->dbh_do($query);
+commonHeader(_("Group Setup") . " - " . _("Group Added"));
 
-PRINT "Added $groupname  <a href=\"$USERPREFIX/setup-groups.php\">Go Back</a>";
+$DB = Config::Database();
+$DB->InsertQuery('groups', array('name' => $groupname));
+
+printf(_("Added %s"), $groupname);
+printf(' <a href="%s">%s</a>', Config::AbsLoc('users/setup-groups.php'),
+				_("Go Back"));
 commonFooter();
-?>
