@@ -16,15 +16,21 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-groups-members-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "INSERT INTO comp_group VALUES ($comp_id, $group_id)";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-
-?>
+$DB = Config::Database();
+$qc = $DB->getTextValue($comp_id);
+$qg = $DB->getTextValue($group_id);
+if (0 == $DB->getOne("SELECT COUNT(*) FROM comp_group WHERE comp_id=$qc AND group_id=$qg"))
+{
+	$vals = array(
+		'comp_id' => $comp_id,
+		'group_id' => $group_id
+		);
+	$DB->InsertQuery('comp_group', $vals);
+}
 
+header("Location: ".$_SESSION['_sess_prevpage']);
