@@ -16,15 +16,14 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-groups-members-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "DELETE FROM comp_group WHERE comp_id = \"$comp_id\" AND group_id = \"$group_id\"";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-
-?>
-
+$DB = Config::Database();
+$comp_id = $DB->getTextValue($comp_id);
+$group_id = $DB->getTextValue($group_id);
+$query = "DELETE FROM comp_group WHERE comp_id = $comp_id AND group_id = $group_id";
+$DB->query($query);
+header("Location: ".$_SESSION['_sess_prevpage']);
