@@ -16,22 +16,20 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-groups-update.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
-commonHeader("IRM Group Setup - Computer Group Updated");
-$query = "REPLACE groups VALUES ('$id', '$groupname')";
-$count = $adb->dbh_do($query);
+commonHeader(_("Group Setup") . " - " . _("Computer Group Updated"));
 
-PRINT "Updated ($id) $groupname <a href=\"$USERPREFIX/setup-groups.php\">Go back</a>";
+$DB = Config::Database();
+$id = $DB->getTextValue($id);
+$DB->UpdateQuery('groups', array('name' => $groupname), "ID=$id");
+
+printf(_("Updated (%s) %s"),$id,$groupname);
+PRINT "<a href=\"".Config::AbsLoc('users/setup-groups.php')."\">"._("Go back")."</a>";
 commonFooter();
-?>
