@@ -16,22 +16,25 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-knowledgebase-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  8/16/99 - Keith Schoenefeld:	Created file for groups stuff.                 #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
-commonHeader("IRM Knowledge Base Setup - Category Added");
-$query = "INSERT INTO kbcategories VALUES (null, '$categorylist', '$categoryname')";
-$count = $adb->dbh_do($query);
+commonHeader(_("Knowledge Base Setup") . " - " . _("Category Added"));
+$vals = array(
+	'parentID' => $categorylist,
+	'name' => $categoryname
+	);
 
-PRINT "Added $categoryname  <a href=\"$USERPREFIX/setup-knowledgebase.php\">Go Back</a>";
+$DB = Config::Database();
+$DB->InsertQuery('kbcategories', $vals);
+
+PRINT "Added $categoryname.";
+PRINT '<a href="'.Config::AbsLoc('users/setup-knowledgebase.php').'">';
+__("Go Back");
+PRINT '</a>';
 commonFooter();
-?>
