@@ -16,22 +16,25 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#  $Id: setup-knowledgebase-update.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("tech");
 
-commonHeader("IRM Knowledge Base Setup - Category Updated");
-$query = "REPLACE kbcategories VALUES ('$id', '$categorylist', '$categoryname')";
-$count = $adb->dbh_do($query);
+commonHeader(_("Knowledge Base Setup") . " - " . _("Category Updated"));
+$vals = array(
+	'parentID' => $categorylist,
+	'name' => $categoryname
+	);
 
-PRINT "Updated ($id) $categoryname <a href=\"$USERPREFIX/setup-knowledgebase.php\">Go back</a>";
+$DB = Config::Database();
+$qid = $DB->getTextValue($id);
+$DB->UpdateQuery('kbcategories', $vals, "ID=$qid");
+
+printf(_("Updated (%s) %s"), $id, $categoryname);
+printf(' <a href="%s">%s</a>', Config::AbsLoc('users/setup-knowledgebase.php'),
+		_("Go back"));
 commonFooter();
-?>
