@@ -16,22 +16,16 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-templates-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
 
 AuthCheck("tech");
 
-header("Location: $HTTP_REFERER");
-$query = "DELETE FROM templates WHERE (ID = \"$ID\")";
-$count = $adb->dbh_do($query);
-$query = "DELETE FROM templ_inst_software WHERE (cID = \"$ID\")";
-$count = $adb->dbh_do($query);
-
-?>
+header("Location: ".$_SESSION['_sess_prevpage']);
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$query = "DELETE FROM templates WHERE (ID = $ID)";
+$DB->query($query);
+$query = "DELETE FROM templ_inst_software WHERE (cID = $ID)";
+$DB->query($query);
