@@ -16,15 +16,15 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-templates-software-add.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "INSERT INTO templ_inst_software VALUES (NULL, $cID, $sID)";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-
-?>
-
+$vals = array(
+	'cID' => $cID,
+	'sID' => $sID
+	);
+$DB = Config::Database();
+$DB->InsertQuery('templ_inst_software', $vals);
+header("Location: ".$_SESSION['_sess_prevpage']);
