@@ -16,18 +16,14 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-templates-software-del.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld: Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
-$query = "DELETE FROM templ_inst_software WHERE (ID = \"$ID\")";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-?>
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$query = "DELETE FROM templ_inst_software WHERE (ID = $ID)";
+$DB->query($query);
+header("Location: ".$_SESSION['_sess_prevpage']);
