@@ -16,28 +16,21 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-user-add.php,v 1.3 2001/07/03 03:06:28 racer Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("admin");
 $user = new User();
-$user->setName($username);
-$user->setPassword($password);
-$user->setFullname($fullname);
-$user->setEmail($email);
-$user->setLocation($location);
-$user->setPhone($phone);
-$user->setType($type);
-$user->setComments($comments);
+$user->setName(@$username);
+$user->setPassword(@$password);
+$user->setFullname(@$fullname);
+$user->setEmail(@$email);
+$user->setLocation(@$location);
+$user->setPhone(@$phone);
+$user->setType(@$type);
+$user->setComments(@$comments);
 $user->add();
-logevent(-1, "IRM", 5, "setup", "$IRMName add user $username.");
-header("Location: $HTTP_REFERER");
-
-?>
+logevent(-1, "IRM", 5, _("setup"), sprintf(_("%s add user %s."),$IRMName, $username));
+header("Location: ".$_SESSION['_sess_prevpage']);
