@@ -16,26 +16,21 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: setup-user-del.php,v 1.3 2001/07/03 03:06:28 racer Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("admin");
 
-commonHeader("IRM User Setup - User Deleted");
+commonHeader(_("User Setup") . " - " . _("User Deleted"));
 $user = new User($username);
 $user->delete();
-logevent(-1, "IRM", 5, "setup", "$IRMName removed user $username");
-?>
-User <?php echo $username; ?> Deleted!  Note: All jobs assigned to/posted by this
-user are <STRONG>not</STRONG> deleted. 
-<?php
-PRINT "<a href=\"$USERPREFIX/setup-users.php\">Go Back</a>";
+logevent(-1, "IRM", 5, "setup", sprintf(_("%s removed user %s"), $IRMName, $username));
+
+printf('User %sDeleted!  Note: All jobs assigned to/posted by this user are not deleted.', $username);
+
+printf('<a href="%s">%s</a>', Config::AbsLoc('users/setup-users.php'),
+		_('Go Back'));
+
 commonFooter();
-?>
