@@ -16,21 +16,22 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: software-add.php,v 1.2.4.1 2003/02/21 05:27:59 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 
-$comments = addslashes($comments);
-$query = "INSERT INTO software VALUES (NULL, '$name','$platform', '$class' , '$comments' )"; 
+$vals = array(
+	'name' => $name,
+	'platform' => $platform,
+	'install_package' => $package,
+	'class' => $class,
+	'comments' => $comments
+	);
 
-$adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
-?>
+$DB = Config::Database();
+$DB->InsertQuery('software', $vals);
+header("Location: ".$_SESSION['_sess_prevpage']
+);
