@@ -16,35 +16,23 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: software-info.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 include("../include/irm.inc");
+require_once 'lib/Config.php';
+require_once 'include/i18n.php';
 
 AuthCheck("normal");
 
-commonHeader("IRM Software - Information");
+commonHeader(_("Software") . " - " . _("Information"));
 
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
 $query = "SELECT ID, class FROM software WHERE (ID = $ID)";
-$sth = $adb->prepare($query);
-if($sth)
-{
-	$res = $sth->execute();
-	$numRows = $sth->rows();
-	$result = $sth->fetchrow_hash();
-	$class = $result["class"];
-	$ID = $result["ID"];
-	showSoftware($ID);
-	if ( $class == 'Application Bundle' ) showBundled($ID);
-	showLicenses($ID);
+$result = $DB->getRow($query);
+$class = $result["class"];
+$ID = $result["ID"];
+showSoftware($ID);
+if ( $class == 'Application Bundle' ) showBundled($ID);
+showLicenses($ID);
 
-} else
-{
-	PRINT "Could not prepare query: ".$sth->errstr."<br>\n";
-}
 commonFooter();
-?>
