@@ -16,22 +16,23 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: software-update.php,v 1.2 2001/06/29 04:07:13 theatrus Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  7/22/99 - Keith Schoenefeld:	Cleaned up code, converted all IF(): to if(){. #
 ################################################################################
 
 require("../include/irm.inc");
+require_once 'lib/Config.php';
 
 AuthCheck("tech");
 
-$comments = addslashes($comments);
-$query = "REPLACE software VALUES ($ID, '$name', '$platform',  
-		'$class', '$comments')";
-$count = $adb->dbh_do($query);
-header("Location: $HTTP_REFERER");
 
-?>
+$vals = array(
+	'name' => $name,
+	'platform' => $platform,
+	'install_package' => $package,
+	'class' => $class,
+	'comments' => $comments
+	);
+
+$DB = Config::Database();
+$ID = $DB->getTextValue($ID);
+$DB->UpdateQuery('software', $vals, "ID=$ID");
+header("Location: ".$_SESSION['_sess_prevpage']);
