@@ -16,32 +16,26 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#    $Id: tracking-search.php,v 1.3 2001/07/16 04:39:29 racer Exp $
-#
-################################################################################
-#                                  CHANGELOG                                   #
-################################################################################
-#  11/06/99 - Yann Ramin: Added file for searching			       #
 ################################################################################
 
 include("../include/irm.inc");
+require_once 'include/i18n.php';
 
 AuthCheck("normal");
 
-commonHeader("IRM Tracking - Search");
+commonHeader(_("Tracking") ." - " . _("Search"));
+
+$trackingIDs = Tracking::search($searchtype, $contains);
 ?>
-<h3>Search Results</h3>
-These are your search results for the query: description contains <?php echo $contains; ?>.
+<h3><?php __("Search Results") ?></h3>
+<?php printf(_("%s tracking item(s) related to %s"),count($trackingIDs),htmlspecialchars($contains)); ?>
 <hr noshade>
 <?php
-$trackingIDs = Tracking::search("contents", $contains);
-$numTrackingIDs = sizeof($trackingIDs);
 Tracking::displayHeader();
-for($i=0; $i < $numTrackingIDs; $i++)
+foreach ($trackingIDs as $ID)
 {
-	$track = new Tracking($trackingIDs[$i]);
+	$track = new Tracking($ID);
 	$track->display();
 }
 Tracking::displayFooter();
 commonFooter();
-?>
